"""
Subpackage modules for the Skunk Works program to develop advanced imaging capabilities for ngCASA.
Functionality in development:
1. Full Mueller Imaging 
2. Zernicke Polynomial Aperture Models
3. Widefield (W projection) Imaging
4. Wideband Imaging
5. Heterogeneous Dish Support 
6. Heterogeneous Pointing Corrections
7. Heterogeneous Beam Squint Correction
"""
from .make_gcf_coords import make_gcf_coords
from .make_gcf import make_gcf

